@@ -1,13 +1,14 @@
 """
-This module checks the authentication of incoming requests. 
+This module implements the functionality for request authentication. The
+classes here are actually mixins, and therefore are not meant to stand on their
+own. They add the authentication functionality to API handler classes.
 Where possible, like in the case of ``SessionAuthentication``, we make use of
 Django's middlewares(which have already ran), to identify whether the request
 is authenticated and who the authenticated user is.
 
-In other cases, we implement the whole logic in the authentication class.
+In other cases, we implement the whole logic in the authentication mixin.
 """
 from django.contrib.auth.models import AnonymousUser
-from django.core.signing import TimestampSigner
 from django.core.signing import BadSignature
 from django.core.signing import SignatureExpired
 from django.utils import timezone
@@ -19,13 +20,15 @@ import time
 
 
 
-class Authentication:
+class Authentication(object):
     """
-    Any of the subclasses of this class, can defined in the ``authentication``
-    parameter of the API handlers, therefore defining the handler's
-    authentication method.
-    The handler's metaclass makes sure that the ``authentication`` class is set
-    as a superclass for the handler, therefore inheriting its functionality.
+    All the mixins of this module, other than ``Authentication`` can be used in
+    the ``authentication`` parameter of any API handler, therefore defining the
+    handler's authentication method.
+
+    The handler's metaclass makes sure that the ``authentication`` class is
+    used as a mixin(superclass) by the handler, therefore inheriting its
+    functionality.
     """
     pass
 
@@ -62,17 +65,10 @@ class SignatureAuthentication(Authentication):
         * HTTP Method
         * URL with querystring parameters (including a parameter indicating the max_age
           of the signature)
-    """
-    def __init__(self, sig_param='s', max_age_param='m'):
-        """
-        @param sig_param:     Querystring parameter that carries the signature
-        @param max_age_param: Querystring parameter that carries the max_age(in
-        seconds of the signature)
-        """
-        self.signer = TimestampSigner()
-        self.sig_param = sig_param
-        self.max_age_param = max_age_param
 
+    Makes use of the handler class parameters ``signer``, ``sig_param``, and
+    ``max_age_param``        
+    """
     def is_authenticated(self):
         """
         Strictly speaking, this is not an authentication check, since we don't
@@ -167,23 +163,16 @@ class SignatureAuthentication(Authentication):
         return '%s:%s' % (parts[1], parts[2])
 
 
-class TokenAuthentication(Authentication):
-    """
-    Token included in ``Authentication``, indicates a token which belongs to a
-    User. Parameter ``request.user`` is set accordingly.
-    """
-    pass
-
-
 class OAuthAuthentication(Authentication, ProtectedResourceView):
-    def __init__(self):
-        # TODO: Check if all apps/middlewares/models are installed correctly.
-        return super(OAuthAuthentication, self).__init__()
+    # TODO: Check if all apps/middlewares/models are installed correctly.
 
     def is_authenticated(self):
+        """
+        Sets the ``self.request.user`` to the user who carries the
+        Authorization token.
+        """
         valid, r = self.verify_request(self.request)
         if valid:
             self.request.user = r.user
             return True
-        else:
-            return False
+        return False
